<?php



namespace WpieApp\Core\Helpers;

use voku\helper\UTF8;
use WpieApp\Core\Admin\AutoLoader;

defined( 'WPIE__FILE__' ) || exit;


trait Str {

        
        public static function isNonEmptyStr( $str = null ) {
                return is_string( $str ) && '' !== trim( $str );
        }

        
        public static function isEmptyStr( $str ) {
                return !self::isNonEmptyStr( $str );
        }

        
        public static function strStartsWith( $needle = "", $str = "" ) {
                return Helper::isNonEmptyStr( $needle ) && mb_substr( $str, 0, mb_strlen( $needle ) ) === ( string ) $needle;
        }

        
        public static function strEndsWith( $str, $needle ) {
                return Helper::isNonEmptyStr( $needle ) && mb_substr( $str, -mb_strlen( $needle ) ) === ( string ) $needle;
        }

        
        public static function contains( $str, $needle ) {
                return Helper::isNonEmptyStr( $needle ) ? mb_stripos( $str, $needle ) !== false : false;
        }

        
        public static function strToArr( $str = "", $sep = ',' ) {

                if ( Helper::isEmptyStr( $str ) ) {
                        return [];
                }

                $parts = explode( Helper::isEmptyStr( $sep ) ? ',' : $sep, trim( $str ) );

                return Helper::isNonEmptyArray( $parts ) ? array_map( 'trim', $parts ) : [];
        }

        
        public static function strToMultiArr( $str = "", $sep = ',', $val = null ) {

                if ( Helper::isEmptyStr( $str ) ) {
                        return [];
                }

                $str = Helper::strTrim( $str, $sep );

                $parts = explode( Helper::isEmptyStr( $sep ) ? ',' : $sep, trim( $str ) );

                $total = count( $parts );

                $part = Helper::sanitizeText( array_shift( $parts ) );

                $arr = [];

                if ( 1 === $total ) {

                        $arr[ $part ] = $val;
                } else {

                        $arr[ $part ] = self::strToMultiArr( Helper::arrTostr( $parts, $sep ), $sep, $val );
                }

                return Helper::isNonEmptyArray( $arr ) ? $arr : [];
        }

        
        public static function toString( $var = null ) {

                if ( is_string( $var ) ) {
                        return $var;
                }

                if ( Helper::isEmpty( $var ) ) {
                        return "";
                }

                if ( is_bool( $var ) ) {
                        return $var ? "1" : "0";
                }

                if ( Helper::isScalar( $var ) ) {
                        return ( string ) $var;
                }

                if ( is_array( $var ) || is_object( $var ) ) {
                        return Helper::jsonEncode( $var );
                }

                return ( string ) $var;
        }

        
        public static function rightTrim( $str = "", $needles = "", $caseSensitive = false ) {

                if ( Helper::isEmptyStr( $str ) ) {
                        return "";
                }

                $str = rtrim( $str );

                if ( !is_array( $needles ) ) {
                        $needles = [ $needles ];
                }
                if ( Helper::isEmpty( $needles ) ) {
                        return $str;
                }

                $strPosFunction = $caseSensitive ? "mb_strpos" : "mb_stripos";

                foreach ( $needles as $needle ) {

                        if ( Helper::isEmptyStr( $needle ) ) {
                                continue;
                        }

                        $offset = mb_strlen( $str ) - mb_strlen( $needle );

                        if ( $offset < 0 ) {
                                continue;
                        }

                        if ( $strPosFunction( $str, $needle, $offset ) !== false ) {
                                $str = mb_substr( $str, 0, -mb_strlen( $needle ) );
                                $str = self::rightTrim( $str, $needle, $caseSensitive );
                        }
                }
                return $str;
        }

        
        public static function leftTrim( $str = "", $needles = "", $caseSensitive = false ) {

                if ( Helper::isEmptyStr( $str ) ) {
                        return "";
                }
                $str = ltrim( $str );

                if ( !is_array( $needles ) ) {
                        $needles = [ $needles ];
                }

                if ( Helper::isEmpty( $needles ) ) {
                        return $str;
                }

                $strPosFunction = $caseSensitive ? "mb_strpos" : "mb_stripos";

                foreach ( $needles as $needle ) {

                        if ( Helper::isEmptyStr( $needle ) ) {
                                continue;
                        }

                        if ( mb_strlen( $str ) - mb_strlen( $needle ) < 0 ) {
                                continue;
                        }

                        if ( $strPosFunction( $str, $needle ) === 0 ) {
                                $str = mb_substr( $str, mb_strlen( $needle ) );
                                $str = self::leftTrim( $str, $needle, $caseSensitive );
                        }
                }

                return $str;
        }

        
        public static function strTrim( $str = "", $needle = "", $caseSensitive = false ) {

                if ( Helper::isNonEmptyArray( $str ) ) {
                        return array_map( [ __CLASS__, 'strTrim' ], $str, array_fill( 0, count( $str ), $needle ), array_fill( 0, count( $str ), $caseSensitive ) );
                }

                if ( !Helper::isNonEmptyStr( $str ) ) {
                        return $str;
                }

                $str = \trim( $str );

                $str = self::leftTrim( $str, $needle, $caseSensitive );

                $str = self::rightTrim( $str, $needle, $caseSensitive );

                return $str;
        }

        
        public static function randStr( $prefix = "" ) {

                $prefix = Helper::isNonEmptyStr( $prefix ) ? $prefix : "";

                return $prefix . (( string ) \time()) . ( string ) \wp_rand();
        }

        
        public static function toUtf8( $str = null ) {

                if ( Helper::isNonEmptyArray( $str ) ) {
                        return array_map( [ __CLASS__, 'toUtf8' ], $str );
                }

                if ( is_numeric( $str ) || is_bool( $str ) || !Helper::isNonEmptyStr( $str ) ) {
                        return $str;
                }

                if ( !is_string( $str ) ) {
                        return $str;
                }

                $str = trim( $str );
                
                AutoLoader::loadGeneral();

                return UTF8::to_utf8( $str );
        }

        
        public static function addPrefix( $data, $prefix = "" ) {

                if ( !Helper::isNonEmptyStr( $prefix ) ) {
                        return $data;
                }

                if ( is_array( $data ) ) {
                        return preg_filter( '/^/', $prefix, $data );
                }

                if ( !Helper::isScalar( $data ) ) {
                        return $data;
                }

                return $prefix . Helper::toString( $data );
        }

        
        public static function autoFixStr( $input = "", $data = [], $matchChar = 3 ) {

                if ( !Helper::isNonEmptyStr( $input ) ) {
                        return "";
                }

                if ( Helper::isNonEmptyStr( $data ) ) {
                        $data = [ $data ];
                }

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return $input;
                }

                if ( in_array( $input, $data ) ) {
                        return $input;
                }

                $matchChar = ($matchChar === false) ? $matchChar : ( Helper::toInt( $matchChar ) < 3 ? 3 : Helper::toInt( $matchChar ));

                $newStr = "";

                foreach ( $data as $str ) {

                        $subStr = ( $matchChar === false || $matchChar >= mb_strlen( $str )) ? $str : mb_substr( $str, 0, $matchChar );

                        if ( self::contains( $input, $subStr ) || self::contains( $subStr, $input ) ) {
                                $newStr = $str;
                                break;
                        }
                }

                return $newStr;
        }
}
