<?php




namespace WpieApp\Core\Helpers;

defined( 'WPIE__FILE__' ) || exit;


trait User {

        
        private static $currentUser;

        
        public static function userInfo() {

                if ( is_null( self::$currentUser ) ) {

                        self::$currentUser = \wp_get_current_user();
                }

                return self::$currentUser;
        }

        
        public static function userId() {
                return \get_current_user_id();
        }

        
        public static function getCurrentUserEmail() {
                return self::userInfo()->user_email;
        }

        
        public static function isAdministrator() {

                if ( in_array( 'administrator', self::userInfo()->roles ) ) {
                        return true;
                }

                return false;
        }

        
        public static function addCurrentUserPermission( $cap = "" ) {

                if ( Helper::isEmptyStr( $cap ) || !self::isAdministrator() ) {
                        return;
                }

                if ( !self::userInfo()->has_cap( $cap ) ) {
                        self::userInfo()->add_cap( $cap );
                }
        }

        
        public static function getUserCapByModule( $module = "" ) {

                if ( Helper::isEmptyStr( $module ) ) {
                        return "";
                }

                $prefix = str_replace( '_', '-', Helper::PLUGIN_PREFIX );

                return \sanitize_title_with_dashes( $prefix . strtolower( $module ) );
        }

        
        public static function userHasPermission() {

                if ( self::isAdministrator() ) {
                        return true;
                }

                $module = Helper::getActiveModule();

                if ( Helper::isEmptyStr( $module ) ) {
                        return false;
                }

                $cap = self::getUserCapByModule( $module );

                if ( Helper::isNonEmptyStr( $cap ) && current_user_can( $cap ) ) {
                        return true;
                }
                return false;
        }

}
