<?php

namespace WpieApp\Core\Office\Reader\CSV;

use WpieApp\Core\Office\Reader\ReaderInterface;
use WpieApp\Core\Helpers\Helper;
use SplFileObject;

defined( 'WPIE__FILE__' ) || exit;


class Reader {

        
        private $handle;

        
        private $labels = [];

        
        private $data = [];

        
        private $delimiter = ",";

        
        private $enclosure = "'";

        
        private $rowNumber = 0;

        
        private $hasTitle = true;

        
        public function load( $file = "", $options = [] ) {

                $handle = Helper::fOpenReadOnly( $file );

                if ( \is_wp_error( $handle ) ) {
                        return $handle;
                }

                $this->handle = $handle;

                $this->setOptions( $options );

//                $this->handle->setCsvControl( $this->delimiter, $this->enclosure );



                $this->setLabels();

                $this->rewind();
                return true;
        }

        
        private function setOptions( $options = [] ) {

                $this->hasTitle = isset( $options[ 'hasTitle' ] ) && is_bool( $options[ 'hasTitle' ] ) ? $options[ 'hasTitle' ] : true;

                //Set Delimiter
                $delimiter = isset( $options[ 'delimiter' ] ) ? $options[ 'delimiter' ] : "";
                $delimiter = Delimiter::get( $this->handle, $delimiter );

                if ( \is_wp_error( $delimiter ) ) {
                        return $delimiter;
                }
                $this->delimiter = \is_string( $delimiter ) && \strlen( $delimiter ) === 1 ? $delimiter : $this->delimiter;

                //Set Delimiter
                $enclosure = isset( $options[ 'enclosure' ] ) ? $options[ 'enclosure' ] : "";
                $enclosure = Enclosure::get( $this->handle, $enclosure, $delimiter );

                if ( \is_wp_error( $enclosure ) ) {
                        return $enclosure;
                }
                $this->enclosure = $enclosure;
        }

        
        public function getLabels() {

                return $this->labels;
        }

        
        private function setLabels() {

                if ( Helper::isNonEmptyArray( $this->labels ) ) {
                        return;
                }

                $this->rewind();

                $this->labels = [];

                $this->next();

                $data = $this->current();

                if ( $this->hasTitle ) {

                        $this->labels = Helper::createUniqueArray( $data );

                        return;
                }

                for ( $i = 1; $i <= count( $data ); $i++ ) {
                        $this->labels[] = "field_" . $i;
                }

                $this->rowNumber = 1;
        }

        
        public function current() {

                if ( $this->rowNumber <= 1 ) {
                        $this->data = $this->removeBom( $this->data );
                }

                $this->data = array_map( [ $this, 'sanitize' ], $this->data );

                return (empty( $this->labels ) ? $this->data : Helper::safeArrayCombine( $this->labels, $this->data ) );
        }

        
        public function get() {

                $this->next();

                return $this->current();
        }

        
        public function key() {
                return $this->rowNumber;
        }

        
        public function nextData() {
                return $this->next();
        }

        
        public function next() {

                $row = \fgetcsv( $this->handle, null, $this->delimiter, $this->enclosure );

                if ( false === $row ) {
                        $this->data = [];
                        return false;
                }

                if ( !is_array( $row ) || $this->isEmptyRow( $row ) ) {
                        return $this->next();
                }

                $this->data = $row;

                $this->rowNumber++;

                return true;
        }

        
        public function goToRow( $offset = 1 ) {

                $this->rewind();

                if ( $offset <= 1 ) {
                        return;
                }

                while ( $this->next() && $offset > $this->rowNumber ) {
                        
                }
        }

        
        public function count() {

                $this->rewind();

                while ( $this->next() ) {
                        
                }

                return $this->rowNumber;
        }

        
        public function rewind() {

                if ( $this->rowNumber < 1 ) {
                        return;
                }

                \rewind( $this->handle );

                if ( $this->hasTitle ) {

                        $this->next();
                }

                $this->next();

                $this->rowNumber = 1;
        }

        
        public function valid() {
                return \feof( $this->handle );
        }

        
        private function removeBom( $row = [] ) {

                if ( $this->isEmptyRow( $row ) || !isset( $row[ 0 ] ) ) {
                        return $row;
                }

                $row[ 0 ] = Helper::removeBom( $row[ 0 ] );

                return $row;
        }

        
        private function isEmptyRow( $row = null ) {

                if ( !Helper::isNonEmptyArray( $row ) ) {
                        return false;
                }
                return strlen( trim( implode( "", $row ) ) ) === 0;
        }

        
        private function unescapeSpecialChar( $data = "" ) {

                if ( Helper::isEmptyStr( $data ) ) {
                        return $data;
                }

                $active_content_triggers = [ "'=", "'+", "'-", "'@" ];

                if ( in_array( mb_substr( trim( $data ), 0, 2 ), $active_content_triggers, true ) ) {
                        $data = mb_substr( $data, 1 );
                }
                return $data;
        }

        
        private function sanitize( $data = "" ) {

                if ( Helper::isEmptyStr( $data ) ) {
                        return $data;
                }

                $data = $this->unescapeSpecialChar( $data );

                return $data;
        }

        
        public function getDelimiter() {
                return $this->delimiter;
        }

        
        public function getEnclosure() {
                return $this->enclosure;
        }

        
        public function getPointer() {
                return ftell( $this->handle );
        }

        
        public function setPointer( $poniter = 0, $row = 0 ) {

                if ( !is_numeric( $poniter ) || $row <= 1 ) {
                        $this->rewind();
                        return;
                }

                \rewind( $this->handle );

                fseek( $this->handle, Helper::toInt( $poniter ) );

                $this->next();

                $this->rowNumber = $row;
        }

        
        public function getRowNumber() {

                return $this->rowNumber;
        }
}
