<?php


namespace WpieApp\Core\Page\Blocks;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Page\Blocks\Fields\Alert;
use WpieApp\Core\Page\Blocks\Templates\Standard\Manager as StandardManager;

defined( 'WPIE__FILE__' ) || exit;


class Fields {

        
        const DEFAULT_FIELD = "text";

        
        private static $fields = [];

        
        private static function getDefaultFields() {

                $fields = [];

                $findFieldClasses = glob( __DIR__ . '/Fields/*' );

                $fieldDir = str_replace( '\\', '/', realpath( __DIR__ . '/Fields' ) );

                foreach ( $findFieldClasses as $fieldClasses ) {

                        $fieldClasses = str_replace( '\\', '/', realpath( $fieldClasses ) );

                        $name = substr( $fieldClasses, strlen( rtrim( $fieldDir, '/' ) ) + 1, -4 );

                        $className = __NAMESPACE__ . "\\Fields\\" . $name;

                        if ( !defined( $className . '::TYPE' ) ) {

                                continue;
                        }
                        $fields[ $className::TYPE ] = $className;
                }

                return $fields;
        }

        
        private static function getFields() {

                if ( Helper::isNonEmptyArray( self::$fields ) ) {
                        return self::$fields;
                }

                
                self::$fields = \apply_filters( 'Wpie/Core/Page/Blocks/Fields', self::getDefaultFields() );

                return self::$fields;
        }

        
        private static function getFieldClass( $name = "" ) {

                $fields = self::getFields();

                if ( Helper::isNonEmptyStr( $name ) && isset( $fields[ $name ] ) ) {
                        return $fields[ $name ];
                }

                return $fields[ self::DEFAULT_FIELD ];
        }

        
        public static function render( $data = [], $options = [] ) {

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return;
                }

                $data = Helper::sortBy( $data );

                foreach ( $data as $page ) {

                        self::addPage( $page, $options );
                }
        }

        
        public static function renderChild( $data = [], $options = [] ) {
                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return;
                }
                ?>
                <div class="wpie-child-field-container mt-2">
                        <div class="row p-0 m-0">
                                <?php self::render( $data, $options ); ?>
                        </div>
                </div>
                <?php
        }

        
        public static function addPage( $fields = [], $options = [] ) {

                if ( !Helper::isNonEmptyArray( $fields ) ) {
                        return;
                }

                $label        = isset( $fields[ "label" ] ) ? $fields[ "label" ] : "";
                $wrapperClass = isset( $fields[ "wrapper-class" ] ) ? Helper::toString( $fields[ "wrapper-class" ] ) : "";
                $wrapperCol   = isset( $fields[ "wrapper-col" ] ) ? Helper::toString( $fields[ "wrapper-col" ] ) : "";

                $subFields = [];

                if ( isset( $fields[ "sub-fields" ] ) ) {
                        $subFields = $fields[ "sub-fields" ];
                } elseif ( isset( $fields[ "type" ] ) ) {
                        $subFields = [ $fields ];
                }

                if ( !Helper::isNonEmptyArray( $subFields ) ) {
                        return;
                }

                $subFields = Helper::sortBy( $subFields );

                $wrapperCol = Helper::isNonEmptyStr( $wrapperCol ) ? $wrapperCol : "col-12";
                ?>

                <div class="wpie-field-wrapper <?php echo esc_attr( $wrapperCol . " " . $wrapperClass ); ?>">
                        <div class="container ">
                                <div class="row gap-3">
                                        <?php
                                        self::addlabel( $label );
                                        foreach ( $subFields as $field ) {
                                                self::addSubFields( $field, $options );
                                        }
                                        ?>

                                </div>
                        </div>
                </div>
                <?php
        }

        
        public static function addSubFields( $field = [], $options = [] ) {

                if ( !Helper::isNonEmptyArray( $field ) ) {
                        return;
                }

                $description  = isset( $field[ "description" ] ) ? Helper::toString( $field[ "description" ] ) : "";
                $notes        = isset( $field[ "notes" ] ) && Helper::isNonEmptyArray( $field[ "notes" ] ) ? $field[ "notes" ] : [];
                $outerClass   = isset( $field[ "outer-class" ] ) ? Helper::toString( $field[ "outer-class" ] ) : "";
                $applyDefault = isset( $field[ "apply-default-class" ] ) && $field[ "apply-default-class" ] === false ? false : true;
                $type         = isset( $field[ "type" ] ) ? Helper::toString( $field[ "type" ] ) : "";
                $bgClass      = isset( $field[ "bg-class" ] ) && Helper::isNonEmptyStr( $field[ "bg-class" ] ) ? Helper::toString( $field[ "bg-class" ] ) : "bg-light";
                $colClass     = isset( $field[ "col-class" ] ) && Helper::isNonEmptyStr( $field[ "col-class" ] ) ? Helper::toString( $field[ "col-class" ] ) : "col-12";
                $proBackdrop  = isset( $field[ "pro-backdrop" ] ) && $field[ "pro-backdrop" ] === true ? true : false;

                if ( $type === "button" && !Helper::isNonEmptyStr( $description ) ) {
                        $outerClass = " ms-0 ps-0 " . $outerClass . " " . $colClass;
                } else {
                        $outerClass = ($applyDefault ? " border p-4 rounded-1 mb-3 " : " ") . $bgClass . " " . $outerClass . " " . $colClass;
                }
                $outerClass = $proBackdrop && !strpos( $outerClass, 'position-relative' ) ? $outerClass . ' position-relative' : $outerClass;

                Alert::addNotes( $notes );
                ?>

                <div class="<?php echo esc_attr( trim( $outerClass ) ); ?>">

                        <?php
                        if ( $proBackdrop ) {
                                StandardManager::addProBackdrop();
                        }
                        self::addDescription( $description );

                        self::addSingleField( $field, $options );
                        ?>
                </div>
                <?php
        }

        
        public static function addSingleField( $field = [], $options = [] ) {

                $type                  = isset( $field[ "type" ] ) ? $field[ "type" ] : "";
                $class                 = isset( $field[ "field-class" ] ) ? $field[ "field-class" ] : "";
                $field[ "group-name" ] = isset( $options[ "group-name" ] ) ? $options[ "group-name" ] : "";

                $fieldClass = self::getFieldClass( $type );

                if ( !method_exists( $fieldClass, "render" ) ) {
                        return;
                }

                if ( isset( $field[ "name" ] ) && Helper::isNonEmptyStr( $field[ "name" ] ) ) {
                        $field[ "name" ] = self::getName( $field );
                }

                echo sprintf( '<div class="wpie-field %s" >', esc_attr( trim( Helper::toString( $class ) ) ) );
                $fieldClass::render( $field );
                self::randerHint( $field );
                echo '</div>';
        }

        
        public static function randerHint( $field = [] ) {

                $data = (isset( $field[ "hint" ] ) ? $field[ "hint" ] : "");

                $hints = Helper::isNonEmptyStr( $data ) ? [ [ 'text' => $data ] ] : $data;

                if ( !Helper::isNonEmptyArray( $hints ) ) {
                        return;
                }
                ?>
                <div class="p-4 border rounded-3 mt-3 bg-white">
                        <div class="form-hint bse-fs-14 pb-2 bse-fw-600 border-bottom " ><?php echo \esc_html__( 'Notes', 'wp-import-export' ); ?></div>
                        <?php
                        foreach ( $hints as $hint ) {
                                $text = (isset( $hint[ "text" ] ) ? $hint[ "text" ] : "");

                                if ( !Helper::isNonEmptyStr( $text ) ) {
                                        continue;
                                }

                                $hintClass = (isset( $hint[ "class" ] ) ? $hint[ "class" ] : "");
                                $hintClass = Helper::isNonEmptyStr( $hintClass ) ? $hintClass : 'text-success';
                                $htmlTags  = isset( $hint[ "allowedTags " ] ) && Helper::isNonEmptyArray( $hint[ "allowedTags " ] ) ? $hint[ "allowedTags " ] : [];
                                ?>
                                <div class="form-hint bse-fs-12 <?php echo \esc_attr( $hintClass ); ?> mt-2" >- <?php echo \wp_kses( $text, Helper::ksesAllowedTags( $htmlTags ) ); ?></div>
                                <?php
                        }
                        ?>
                </div>
                <?php
        }

        
        public static function getName( $field = [] ) {

                if ( !isset( $field[ "name" ] ) || !Helper::isNonEmptyStr( $field[ "name" ] ) ) {
                        return "";
                }

                $prefix = "wpie-settings";

                if ( Helper::strStartsWith( $prefix, $field[ "name" ] ) ) {
                        return $field[ "name" ];
                }

                $groupName = isset( $field[ "group-name" ] ) ? $field[ "group-name" ] : "";

                if ( Helper::isNonEmptyStr( $groupName ) ) {
                        $prefix .= "[" . Helper::arrTostr( Helper::strToArr( $groupName, '/' ), "][" ) . "]";
                }
                return $prefix . "[" . Helper::arrTostr( Helper::strToArr( $field[ "name" ], '/' ), "][" ) . "]";
        }

        
        public static function addlabel( $label = "" ) {

                if ( !Helper::isNonEmptyStr( $label ) ) {
                        return;
                }
                ?>
                <div class="col-12 m-0 p-0">
                        <div class="wpie-field-label mb-3 border-bottom pb-2 bse-text-orange bse-fw-600 bse-fs-16"><?php echo esc_html( $label ); ?></div>
                </div>
                <?php
        }

        
        public static function addDescription( $description = "" ) {

                if ( !Helper::isNonEmptyStr( $description ) ) {
                        return;
                }
                ?>
                <div class="wpie-field-description mb-3 bse-fs-14 text-secondary "><?php echo esc_html( $description ); ?></div>
                <?php
        }
}
