<?php


namespace WpieApp\Core\Page\Blocks\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Page\Blocks\Fields\Alert;

defined( 'WPIE__FILE__' ) || exit;


class ImportLog {

        
        const TYPE = "import-log";

        
        public static function render( $field ) {

                $templates = DB::wpdb()->get_results( "SELECT `id`,`total`,`log`,`content_type`,`category`,`process_type`,`options`,`status`,`file`,`created_date`,`updated_date` FROM " . DB::getPluginTable() . " where `process` = 'import' AND `process_type` IN ('regular','background') AND `status` NOT IN ('draft','init') ORDER BY `id` DESC", ARRAY_A );

                $emptyClass = Helper::isNonEmptyArray( $templates ) ? "d-none" : "";
                ?>
                <div class="wpie-log-wrapper">
                        <div class="wpie-log-empty-wrapper bg-light <?php echo esc_attr( $emptyClass ); ?>">
                                <div class="text-center m-auto py-4 bse-fw-600 bse-text-18"><?php esc_html_e( 'No records found', 'wp-import-export' ); ?></div>
                        </div>

                        <?php
                        if ( Helper::isNonEmptyArray( $templates ) ) {
                                self::renderData( $templates );
                        }
                        ?>
                </div>

                <?php
        }

        
        private static function renderData( $templates ) {

                $bgUid = Helper::randStr( "wpie-modal-" );
                ?>
                <div class="col-12 wpie-log-alert">
                        <?php
                        Alert::render(
                                [
                                        "type"       => "danger",
                                        "icon-class" => "fa-solid fa-triangle-exclamation",
                                        "class"      => "mb-4",
                                        "text"       => __( 'Only imports running in the background can be paused, resumed or stopped', 'wp-import-export' )
                                ]
                        );
                        ?>
                </div>
                <div class="wpie-import-log-wrapper wpie-log-container bg-white container bse-fs-12">
                        <div class="row py-4 border rounded-3 bg-primary bg-opacity-10 p-3">
                                <div class="col my-auto">
                                        <div class="wpie-field">
                                                <select class="form-control form-select wpie-select wpie-bulk-actions" data-minimum-results-for-search="Infinity" data-placeholder="<?php esc_html_e( 'Bulk Actions', 'wp-import-export' ); ?>" >
                                                        <option></option>
                                                        <option value="remove"><?php esc_html_e( 'Remove', 'wp-import-export' ); ?></option>
                                                        <option value="paused"><?php esc_html_e( 'Pause', 'wp-import-export' ); ?></option>
                                                        <option value="resume"><?php esc_html_e( 'Resume', 'wp-import-export' ); ?></option>
                                                        <option value="stopped"><?php esc_html_e( 'Stop', 'wp-import-export' ); ?></option>
                                                        <option value="background"><?php esc_html_e( 'Set Background Processing', 'wp-import-export' ); ?></option>
                                                </select>
                                        </div>
                                </div>
                                <div class="col-auto my-auto">
                                        <div class="wpie-field">
                                                <button type="button" class="btn wpie-bulk-action-btn btn-primary"><i class="bse-fs-14 me-1 fa-solid fa-check"></i><?php esc_html_e( 'Apply', 'wp-import-export' ); ?></button>
                                        </div>
                                </div>
                        </div>
                        <div class="row py-4 border rounded-3 bg-primary bg-opacity-10 p-3 mt-3">
                                <div class="col my-auto">
                                        <div class="wpie-field">
                                                <select class="form-control form-select wpie-select wpie-log-filter" data-minimum-results-for-search="Infinity" data-placeholder="<?php esc_html_e( 'Filter Entries', 'wp-import-export' ); ?>" >
                                                        <option></option>
                                                        <option value="all"><?php esc_html_e( 'All Logs', 'wp-import-export' ); ?></option>
                                                        <option value="processing"><?php esc_html_e( 'Processing', 'wp-import-export' ); ?></option>
                                                        <option value="paused"><?php esc_html_e( 'Paused', 'wp-import-export' ); ?></option>
                                                        <option value="completed"><?php esc_html_e( 'Completed', 'wp-import-export' ); ?></option>
                                                        <option value="failed"><?php esc_html_e( 'Failed', 'wp-import-export' ); ?></option>
                                                        <option value="stopped"><?php esc_html_e( 'Stopped', 'wp-import-export' ); ?></option>
                                                        <option value="background"><?php esc_html_e( 'Background Processing', 'wp-import-export' ); ?></option>
                                                </select>
                                        </div>
                                </div>

                        </div>
                        <div class="row py-4 border rounded-3 bg-primary wpie-filter-empty-record bg-opacity-10 p-3 mt-3 d-none">
                                <div class="col my-auto">
                                        <div class="wpie-field">
                                                <div class="wpie-log-wrapper">
                                                        <div class=" bg-light ">
                                                                <div class="text-center m-auto py-4 bse-fw-600 bse-text-18"><?php esc_html_e( 'No records found', 'wp-import-export' ); ?></div>
                                                        </div>

                                                </div>
                                        </div>
                                </div>

                        </div>
                        <div class="row py-4 bse-fw-600 wpie-log-records-container">
                                <div class="col-auto m-auto">
                                        <div class="form-check ">
                                                <input type="checkbox" class="form-check-input form-checkbox wpie-check-all" value="" />
                                        </div>
                                </div>
                                <div class="col m-auto"><?php esc_html_e( 'File', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Content Type', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Date', 'wp-import-export' ); ?></div>
                                <div class="col m-auto"><?php esc_html_e( 'Summary', 'wp-import-export' ); ?></div>
                        </div>
                        <?php
                        foreach ( $templates as $data ) {

                                $id          = isset( $data[ 'id' ] ) ? $data[ 'id' ] : "";
                                $file        = isset( $data[ 'file' ] ) ? $data[ 'file' ] : "";
                                $date        = isset( $data[ 'created_date' ] ) ? Date::getLocal( $data[ 'created_date' ] ) : "";
                                $updatedDate = isset( $data[ 'updated_date' ] ) ? Date::getLocal( $data[ 'updated_date' ] ) : "";
                                $category    = isset( $data[ 'category' ] ) ? $data[ 'category' ] : "";
                                $contentType = isset( $data[ 'content_type' ] ) ? $data[ 'content_type' ] : "";
                                $status      = isset( $data[ 'status' ] ) ? $data[ 'status' ] : "";
                                $processType = isset( $data[ 'process_type' ] ) ? $data[ 'process_type' ] : "";
                                $total       = isset( $data[ 'total' ] ) ? $data[ 'total' ] : "";
                                $log         = isset( $data[ 'log' ] ) && Helper::isNonEmptyStr( $data[ 'log' ] ) ? maybe_unserialize( $data[ 'log' ] ) : [];
                                $processed   = isset( $log[ 'processed' ] ) ? $log[ 'processed' ] : 0;
                                $updated     = isset( $log[ 'updated' ] ) ? $log[ 'updated' ] : 0;
                                $created     = isset( $log[ 'created' ] ) ? $log[ 'created' ] : 0;
                                $skipped     = isset( $log[ 'skipped' ] ) ? $log[ 'skipped' ] : 0;
                                $statusClass = self::getStatusClass( $status );
                                $options     = isset( $data[ 'options' ] ) && Helper::isNonEmptyStr( $data[ 'options' ] ) ? \maybe_unserialize( $data[ 'options' ] ) : [];

//                                echo '<pre>';
//                                print_R($options);
                                $error = "";
                                if ( $status === "failed" ) {
                                        $options = isset( $data[ 'options' ] ) && Helper::isNonEmptyStr( $data[ 'options' ] ) ? \maybe_unserialize( $data[ 'options' ] ) : [];
                                        $error   = isset( $options[ 'error' ] ) ? $options[ 'error' ] : "";
                                }

                                $bgClass = ('background' === $processType) && !in_array( $status, [ 'completed', 'cancelled', 'failed', 'stopped' ] ) ? 'wpie-log-background' : '';

                                $contentTypeLabel = (isset( $options[ 'Info' ] ) && isset( $options[ 'Info' ][ 'Content' ] ) && isset( $options[ 'Info' ][ 'Content' ][ 'Label' ] ) ? $options[ 'Info' ][ 'Content' ][ 'Label' ] : '');
                                ?>
                                <div class="row border-top py-4 wpie-log wpie-log-<?php echo esc_attr( $id ) ?> wpie-log-<?php echo esc_attr( $status ) ?> <?php echo esc_attr( $bgClass ) ?>" log-id="<?php echo esc_attr( $id ) ?>">
                                        <div class="col-auto m-auto">
                                                <div class="form-check ">
                                                        <input type="checkbox" class="form-check-input form-checkbox wpie-check wpie-export-log-ids" value="<?php echo esc_attr( $id ) ?>" />
                                                </div>
                                        </div>
                                        <div class="col m-auto">
                                                <div><?php echo esc_html( $file ); ?></div>
                                                <div class="bse-fs-20 mt-2">
                                                        <i class="fa-solid fa-trash text-danger me-3 bse-cursor-pointer wpie-process-action-btn wpie-remove-log-btn" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Remove Record', 'wp-import-export' ); ?>"></i>
                                                        <?php if ( !in_array( $status, [ 'completed', 'cancelled', 'failed', 'stopped', 'pre-completed' ] ) ) { ?>
                                                                <i class="fa-solid fa-arrows-spin me-3 text-success bse-cursor-pointer wpie-process-action-btn wpie-background-process-btn <?php echo ('background' === $processType) ? esc_attr( 'd-none' ) : ''; ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'set import in background', 'wp-import-export' ); ?>"></i>
                                                        <?php } ?>
                                                        <i class="fa-solid fa-file me-3 text-primary bse-cursor-pointer wpie-download-process-file wpie-download-import-file" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Download File', 'wp-import-export' ); ?>"></i>
                                                        <i class="fa-solid fa-file-lines text-secondary bse-cursor-pointer me-3 wpie-download-process-log" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Download Import Log', 'wp-import-export' ); ?>"></i>
                                                        <i class="fa-solid fa-circle-play me-3 text-success bse-cursor-pointer wpie-process-action-btn wpie-resume-process-btn <?php
                                                        if ( $status !== "paused" || 'background' !== $processType ) {
                                                                echo esc_attr( 'd-none' );
                                                        }
                                                        ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Resume Import', 'wp-import-export' ); ?>"></i>
                                                        <i class="fa-solid fa-circle-pause me-3 text-primary bse-cursor-pointer wpie-process-action-btn wpie-pause-process-btn <?php
                                                        if ( !in_array( $status, [ 'processing', 'waiting' ] ) || 'background' !== $processType ) {
                                                                echo esc_attr( 'd-none' );
                                                        }
                                                        ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Pause Import', 'wp-import-export' ); ?>"></i>
                                                        <i class="fa-solid fa-circle-stop me-3 text-danger bse-cursor-pointer wpie-process-action-btn wpie-stop-process-btn <?php
                                                        if ( in_array( $status, [ 'completed', 'cancelled', 'failed', 'stopped', 'pre-completed' ] ) ) {
                                                                echo esc_attr( 'd-none' );
                                                        }
                                                        ?>" data-bs-toggle="tooltip" title="<?php esc_attr_e( 'Stop Import', 'wp-import-export' ); ?>"></i>

                                                </div>
                                        </div>
                                        <div class="col m-auto">
                                                <?php if ( Helper::isNonEmptyStr( $contentTypeLabel ) ) { ?>
                                                        <div class="text-primary bse-fw-600"><?php echo esc_html( $contentTypeLabel ); ?></div> 
                                                <?php } ?>
                                                <div class="text-success"><?php echo esc_html( $category . " => " . $contentType ); ?></div>

                                        </div>
                                        <div class="col m-auto">
                                                <div><?php esc_html_e( 'Start', 'wp-import-export' ); ?></div>
                                                <div class="text-success"><?php echo esc_html( $date ); ?></div>
                                                <div class="mt-3"><?php esc_html_e( 'Last Run', 'wp-import-export' ); ?></div>
                                                <div class="text-success"><?php echo esc_html( $updatedDate ); ?></div>
                                        </div>
                                        <div class="col m-auto">
                                                <div><?php esc_html_e( 'Status', 'wp-import-export' ); ?> : <strong class="wpie-log-status <?php echo esc_attr( $statusClass ) ?>"><?php echo \esc_html( self::getStatusText( $status ) ); ?></strong></div>
                                                <?php if ( !in_array( $status, [ 'completed', 'cancelled', 'failed', 'stopped' ] ) ) { ?>
                                                        <div class="wpie-log-status-background-text <?php echo ('background' === $processType) ? '' : esc_attr( 'd-none' ); ?>"><?php esc_html_e( 'Processing', 'wp-import-export' ); ?> : <strong class="text-primary"><?php esc_html_e( 'In background', 'wp-import-export' ); ?> </strong></div>
                                                <?php } ?>
                                                <div><?php esc_html_e( 'Total', 'wp-import-export' ); ?> : <strong><?php echo esc_html( $total ); ?></strong></div>
                                                <div><?php esc_html_e( 'Processed', 'wp-import-export' ); ?> : <strong><?php echo esc_html( $processed ); ?></strong></div>
                                                <div><?php esc_html_e( 'Updated', 'wp-import-export' ); ?> : <strong><?php echo esc_html( $updated ); ?></strong></div>
                                                <div><?php esc_html_e( 'Created', 'wp-import-export' ); ?> : <strong><?php echo esc_html( $created ); ?></strong></div>
                                                <div><?php esc_html_e( 'Skipped', 'wp-import-export' ); ?> : <strong><?php echo esc_html( $skipped ); ?></strong></div>

                                        </div>
                                        <?php if ( Helper::isNonEmptyStr( $error ) ) { ?>
                                                <div class="col-12 mt-3 text-danger bse-fs-12 mb-3"><span class="bse-fw-600 bse-fs-14"><?php esc_html_e( 'Error', 'wp-import-export' ); ?> : </span><?php echo esc_html( $error ); ?></div>
                                        <?php } ?>
                                </div>
                                <?php
                        }
                        ?>

                </div>
                <div class="modal fade <?php echo esc_attr( $bgUid ); ?> wpie-process-bg-notice-modal">
                        <div class="modal-dialog  modal-dialog-centered modal-lg modal-dialog-scrollable">
                                <div class="modal-content">
                                        <div class="modal-header">
                                                <h5 class="modal-title" ><?php esc_html_e( 'Import/Export In Background', 'wp-import-export' ); ?></h5>
                                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                        </div>
                                        <div class="modal-body p-4 bg-white bg-opacity-75">
                                                <div class="wpie-backdrop container">
                                                        <div class="row text-center">                                        
                                                                <div class="col-12 mb-3">
                                                                        <i class="fa-solid fa-lock bse-fs-24 p-3 rounded-circle border border-danger text-danger border-2 "></i>
                                                                </div>                                        
                                                                <div class="col-12 mb-3 bse-fs-18 text-danger bse-fw-600">
                                                                        <?php esc_html_e( 'Setup Required', 'wp-import-export' ); ?>
                                                                </div>
                                                                <div class="col-12 mb-5 ">
                                                                        <?php esc_html_e( 'Import/Export In Background required 2 min cron to import data. Please click on "Setup Guide" button for setup instruction.', 'wp-import-export' ); ?>
                                                                </div>
                                                                <div class="col-auto align-self-center m-auto">
                                                                        <a target="_blank" href="<?php echo \esc_url( Helper::adminUrl( 'wpie-background' ) ); ?>" target="_blank" class="btn btn-lg mx-3 btn-success"><i class="fa-solid fa-lock-open me-2"></i><?php esc_html_e( 'Setup Guide', 'wp-import-export' ); ?></a>
                                                                </div>                                       
                                                        </div>
                                                </div>
                                        </div>
                                </div>
                        </div>
                </div>

                <?php
        }

        
        public static function getStatusClass( $status ) {

                $statusClass = '';

                switch ( $status ) {
                        case 'completed':
                                $statusClass = 'text-success';
                                break;
                        case 'cancelled':
                        case 'failed':
                        case 'stopped':
                                $statusClass = 'text-danger';
                                break;
                        case 'paused':
                                $statusClass = 'text-primary';
                                break;
                }

                return $statusClass;
        }

        
        public static function getStatusText( $status = '' ) {

                switch ( $status ) {
                        case 'waiting':
                                $status = __( 'Waiting for the next iteration', 'wp-import-export' );
                                break;
                }

                return \ucfirst( $status );
        }
}
