<?php



namespace WpieApp\Core\Resource;

defined( 'WPIE__FILE__' ) || exit;


class Memory {

	
	private static $isMaximumLimit = false;

	
	private static $memoryLimit;

	
	const MAX_LIMIT = 90;

	
	public static function isExceeded( $limit = 0 ) {

		$limit = \absint( $limit ) > 0 ? $limit : self::MAX_LIMIT;

		if ( self::getUsagePer() >= \absint( $limit ) ) {
			return true;
		}

		return false;
	}

	
	public static function increase() {

		if ( self::$isMaximumLimit ) {
			return;
		}

		self::$isMaximumLimit = true;

		if ( function_exists( '\wp_raise_memory_limit' ) ) {
			return \wp_raise_memory_limit( 'admin' );
		}

		return true;
	}

	
	private static function getMemoryLimit() {

		if ( self::$memoryLimit ) {
			return self::$memoryLimit;
		}

		if ( function_exists( '\ini_get' ) ) {
			$memory = \ini_get( 'memory_limit' );
		} else {
			// Sensible default.
			$memory = '128M';
		}

		if ( !$memory || -1 === $memory ) {
			// Unlimited, set to 32GB.
			$memory = '32000M';
		}

		self::$memoryLimit = \wp_convert_hr_to_bytes( $memory );

		return self::$memoryLimit;
	}

	
	private static function getUsagePer() {

		$totalMemory = self::getMemoryLimit();

		$usedMemory = \memory_get_usage( true );

		if ( $totalMemory < $usedMemory ) {
			return 100;
		}

		return ($usedMemory * 100) / $totalMemory;
	}

}
