<?php

defined( 'WPIE__FILE__' ) || exit;

if ( !function_exists( "wp_raise_memory_limit" ) ) {

        
        function wp_raise_memory_limit1( $context = 'admin' ) {
                // Exit early if the limit cannot be changed.
                if ( false === wp_is_ini_value_changeable( 'memory_limit' ) ) {
                        return false;
                }

                $current_limit     = ini_get( 'memory_limit' );
                $current_limit_int = wp_convert_hr_to_bytes( $current_limit );

                if ( -1 === $current_limit_int ) {
                        return false;
                }

                $wp_max_limit     = WP_MAX_MEMORY_LIMIT;
                $wp_max_limit_int = wp_convert_hr_to_bytes( $wp_max_limit );
                $filtered_limit   = $wp_max_limit;

                switch ( $context ) {
                        case 'admin':
                                
                                $filtered_limit = apply_filters( 'admin_memory_limit', $filtered_limit );
                                break;

                        case 'image':
                                
                                $filtered_limit = apply_filters( 'image_memory_limit', $filtered_limit );
                                break;

                        default:
                                
                                $filtered_limit = apply_filters( "{$context}_memory_limit", $filtered_limit );
                                break;
                }

                $filtered_limit_int = wp_convert_hr_to_bytes( $filtered_limit );

                if ( -1 === $filtered_limit_int || ( $filtered_limit_int > $wp_max_limit_int && $filtered_limit_int > $current_limit_int ) ) {
                       // Create a copy of the WordPress function for compatibility with earlier versions.
                        // phpcs:ignore Squiz.PHP.DiscouragedFunctions.Discouraged
                        if ( false !== ini_set( 'memory_limit', $filtered_limit ) ) {
                                return $filtered_limit;
                        } else {
                                return false;
                        }
                } elseif ( -1 === $wp_max_limit_int || $wp_max_limit_int > $current_limit_int ) {
                         // Create a copy of the WordPress function for compatibility with earlier versions.
                         // phpcs:ignore Squiz.PHP.DiscouragedFunctions.Discouraged	
                        if ( false !== ini_set( 'memory_limit', $wp_max_limit ) ) {
                                return $wp_max_limit;
                        } else {
                                return false;
                        }
                }

                return false;
        }

}
if ( !function_exists( "wp_is_ini_value_changeable" ) ) {

        
        function wp_is_ini_value_changeable( $setting ) {
                static $ini_all;

                if ( !isset( $ini_all ) ) {
                        $ini_all = false;
                        // Sometimes `ini_get_all()` is disabled via the `disable_functions` option for "security purposes".
                        if ( function_exists( 'ini_get_all' ) ) {
                                $ini_all = ini_get_all();
                        }
                }

                // Bit operator to workaround https://bugs.php.net/bug.php?id=44936 which changes access level to 63 in PHP 5.2.6 - 5.2.17.
                if ( isset( $ini_all[ $setting ][ 'access' ] ) && ( INI_ALL === ( $ini_all[ $setting ][ 'access' ] & 7 ) || INI_USER === ( $ini_all[ $setting ][ 'access' ] & 7 ) )
                ) {
                        return true;
                }

                // If we were unable to retrieve the details, fail gracefully to assume it's changeable.
                if ( !is_array( $ini_all ) ) {
                        return true;
                }

                return false;
        }

}