<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard;

use Automattic\WooCommerce\Internal\DataStores\Orders\OrdersTableQuery;
use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Engine\Base;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Query\Order;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends Base {

        
        protected static function getData() {

                
                \do_action( 'Wpie/Export/WooCommerce/Order/Start', Settings::getContentType() );

                static::initFilter();

                $args = static::buildQuery();

                $data = Order::query( $args );

                if ( self::$action === "total" ) {
                        return $data;
                }

                return static::processData( $data );
        }

        
        protected static function processData( $data = [] ) {
                return DataCenter::init( $data, self::$action );
        }

        
        protected static function initFilter() {

                
                \do_action( 'Wpie/Export/WooCommerce/Order/Filter/Start' );

                Filter::init();

                
                \do_action( 'Wpie/Export/WooCommerce/Order/Filter/Init' );

                static::initBaseFilter();

                self::$where = Filter::getWhere();
                self::$join  = Filter::getJoin();
        }

        
        protected static function buildQuery() {

                $query = [];

                $preQuery = parent::buildQuery();

                if ( Helper::isNonEmptyArray( $preQuery ) ) {
                        $query = $preQuery;
                }

                if ( self::$action === "total" ) {
                        $query[ 'count' ] = true;
                } elseif ( self::$action === "preview" ) {
                        $query[ 'offset' ] = Helper::toInt( Helper::_post( 'row' ) ) > 0 ? Helper::toInt( Helper::_post( 'row' ) ) - 1 : 0;
                        $query[ 'limit' ]  = 1;
                } else {
                        $query[ 'limit' ]  = Settings::recordsPerIteration();
                        $query[ 'offset' ] = Settings::getLog( 'processed' );
                }

                $query[ 'where' ] = self::filterWhere();

                $query[ 'join' ] = self::filterJoin();

                
                return \apply_filters( 'Wpie/Export/WooCommerce/Order/Query', $query );
        }
}
