<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use Automattic\WooCommerce\Internal\DataStores\Orders\OrdersTableDataStore;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;

defined( 'WPIE__FILE__' ) || exit;


class Meta implements InterfaceField {

        
        const FIELD_TYPE = "meta";

        
        public static function get() {

                $fields = [
                        "title"       => esc_html__( "Meta Fields", 'wp-import-export' ),
                        "priority"    => 150,
                        "dateCompare" => true,
                        "data"        => static::getFields()
                ];

                
                return \apply_filters( 'Wpie/Export/Order/Fields/Meta', $fields );
        }

        
        public static function getFields() {

                $keys = static::getMetaKeys();

                
                $keys = \apply_filters( 'Wpie/Export/Order/Fields/Meta/Pre', $keys );

                if ( !Helper::isNonEmptyArray( $keys ) ) {
                        return [];
                }

                return Helper::getNormalizedField( $keys, static::FIELD_TYPE );
        }

        
        protected static function getMetaKeys() {

                
                $limit = \apply_filters( 'Wpie/Export/Order/Fields/Meta/Limit', 500 );

                $limit = is_numeric( $limit ) ? DB::wpdb()->prepare( '%d', $limit ) : 500;

                $excludes = static::getExcludesMetaQuery();

                $keys = DB::wpdb()->get_col(
                        "SELECT DISTINCT `meta_key`
				FROM " . OrdersTableDataStore::get_meta_table_name() . "
				WHERE 1 = 1
                                        $excludes
                                ORDER BY `id` ASC
				LIMIT " . $limit
                );

                return $keys;
        }

        
        protected static function getExcludesMeta() {

                $excludes = [ '_cart_hash', 'is_vat_exempt' ];

                
                $excludes = apply_filters( 'Wpie/Export/Order/Fields/Meta/Excludes', $excludes );

                return Helper::isNonEmptyArray( $excludes ) ? array_unique( $excludes ) : [];
        }

        
        protected static function getExcludesMetaQuery() {

                $query = [
                        " AND `meta_key` NOT LIKE '_edit%' ",
                        " AND `meta_key` NOT LIKE '_refund%' ",
                        " AND `meta_value` != '' ",
                ];

                $keys = DB::prepareData( static::getExcludesMeta() );

                if ( Helper::isNonEmptyStr( $keys ) ) {
                        $query[] = " AND `meta_key` NOT IN ( " . $keys . " ) ";
                }

                
                $query = \apply_filters( 'Wpie/Export/Order/Fields/Meta/Query/Where', $query );

                return Helper::isNonEmptyArray( $query ) ? implode( " ", array_unique( $query ) ) : "";
        }
}
