<?php



namespace WpieApp\Extensions\Import\Acf\Controller\Items\Base\Fields;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Content extends Base {

        
        protected static $fieldTypes = [ 'acfe_code_editor', 'file', 'font-awesome', 'gallery', 'image', 'image_aspect_ratio_crop', 'photo_gallery', 'wysiwyg', 'oembed' ];

        
        public static function getField( $field = [], $order = 5 ) {

                $type = isset( $field[ 'type' ] ) ? $field[ 'type' ] : "";

                if ( !in_array( $type, [ 'gallery', 'photo_gallery' ] ) ) {
                        return parent::getField( $field, $order );
                }

                $key = isset( $field[ 'key' ] ) ? $field[ 'key' ] : "";

                $label = isset( $field[ 'label' ] ) ? $field[ 'label' ] : "";

                return [
                        "title"    => $label,
                        "desc"     => $label,
                        "order"    => $order,
                        "isActive" => 5 === $order,
                        "fields"   => [
                                "field" => [
                                        "order"      => 5,
                                        "label"      => $label,
                                        "sub-fields" => [
                                                "field"     => [
                                                        "description" => $label,
                                                        "name"        => "fields/acf/" . $key . "/data",
                                                        "type"        => "textarea",
                                                        "hint"        => static::getHints( $type )
                                                ],
                                                "separator" => [
                                                        "description" => __( 'Multiple urls Separator', 'wp-import-export' ),
                                                        "name"        => "fields/acf/" . $key . "/separator",
                                                        "type"        => "textarea",
                                                        "hint"        => [
                                                                [ 'text' => __( 'Optional', 'wp-import-export' ) ],
                                                                [ 'text' => __( 'Default : ||', 'wp-import-export' ) ],
                                                                [ 'text' => __( 'Multiple urls separated by', 'wp-import-export' ) ],
                                                        ]
                                                ]
                                        ],
                                ],
                        ]
                ];
        }

        
        protected static function getHints( $type = '' ) {

                $hints = parent::getHints( $type );

                switch ( $type ) {
                        case 'file';
                                $hints[] = [ 'text' => __( 'Enter file Url', 'wp-import-export' ) ];
                                $hints[] = [ 'text' => __( 'File Downloaded from url', 'wp-import-export' ) ];
                                $hints[] = [ 'text' => __( 'Multiple files are separated by ,( comma )', 'wp-import-export' ) ];
                                break;
                        case 'image';
                        case 'image_aspect_ratio_crop';
                                $hints[] = [ 'text' => __( 'Enter image Url', 'wp-import-export' ) ];
                                $hints[] = [ 'text' => __( 'Image Downloaded from url', 'wp-import-export' ) ];
                                break;
                        case 'gallery';
                        case 'photo_gallery';
                                $hints[] = [ 'text' => __( 'Supports multiple images', 'wp-import-export' ) ];
                                $hints[] = [ 'text' => __( 'Enter image Url', 'wp-import-export' ) ];
                                $hints[] = [ 'text' => __( 'Image Downloaded from url', 'wp-import-export' ) ];
                                break;
                        case 'font-awesome';
                                $hints[] = [ 'text' => __( 'Supports json format support', 'wp-import-export' ) ];
                                $hints[] = [ 'text' => __( 'example : {"family" : "classic", "style" : "solid", "id" : "map", "label" : "Map", "unicode" : "f279"}', 'wp-import-export' ) ];
                                break;
                }

                return $hints;
        }
}
