<?php



namespace WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Post;

use AIOSEO\Plugin\Common\Models\Post;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Base\Engines\Social;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Post\Engines\General;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Post\Engines\Facebook;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Post\Engines\Twitter;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Post\Engines\Advanced;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Post\Engines\Schema;

defined( 'WPIE__FILE__' ) || exit;


class Engine {

        
        public static function init() {

                if ( !self::isValidPost() ) {
                        return;
                }

                Social::init();

                $newData = \array_merge(
                        General::get(),
                        Facebook::get(),
                        Twitter::get(),
                        Advanced::get(),
                        Schema::get()
                );

                $existingData = self::getExistingData();

                $skipUpdateData = array_diff_key( $existingData, $newData );

                Post::savePost(
                        DataCenter::getId(),
                        \array_merge( $skipUpdateData, $newData )
                );
        }

        
        public static function getExistingData() {

                if ( DataCenter::isNewItem() ) {
                        return [];
                }

                $post = Post::getPost( DataCenter::getId() );

                $data = Helper::jsonDecode( Helper::jsonEncode( $post ), true );

                // Decode these below because `savePost()` expects them to be an array.
                if ( isset( $data[ 'keyphrases' ] ) && !empty( $data[ 'keyphrases' ] ) ) {
                        $data[ 'keyphrases' ] = Helper::jsonDecode( $data[ 'keyphrases' ], true );
                }

                if ( isset( $data[ 'page_analysis' ] ) && !empty( $data[ 'page_analysis' ] ) ) {
                        $data[ 'page_analysis' ] = Helper::jsonDecode( $data[ 'page_analysis' ], true );
                }

                return $data;
        }

        
        public static function isValidPost() {

                if ( self::isVariation() ) {
                        return false;
                }

                return true;
        }

        
        public static function isVariation() {

                if ( 'wc' !== Settings::get( 'category' ) || 'product' !== Settings::get( 'content_type' ) ) {
                        return false;
                }

                if ( 'product_variation' !== DataCenter::getItem()->post_type ) {
                        return false;
                }

                return true;
        }
}
