<?php



namespace WpieApp\Extensions\Import\RankMathSeo\Controller\Items\Base\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Advanced {

        
        public static function get() {

                $data = [];

                if ( DataCenter::canUpdate( 'rankmathseo/advanced/canonical_url' ) ) {
                        $data[ "canonical_url" ] = DataCenter::get( 'rankmathseo/advanced/canonical_url/data' );
                }

                if ( DataCenter::canUpdate( 'rankmathseo/advanced/breadcrumb_title' ) ) {
                        $data[ "breadcrumb_title" ] = DataCenter::get( 'rankmathseo/advanced/breadcrumb_title/data' );
                }

                return \array_merge( $data, self::getRobots(), self::getRobotsAdv() );
        }

        
        private static function getRobots() {

                $fields = [ 'noindex', 'nofollow', 'noarchive', 'noimageindex', 'nosnippet' ];

                $data = DataCenter::isNewItem() ? [] : static::getMeta( 'robots', true );

                $data = Helper::isNonEmptyArray( $data ) ? $data : [];

                foreach ( $fields as $field ) {

                        if ( !DataCenter::canUpdate( 'rankmathseo/advanced/' . $field ) ) {
                                continue;
                        }

                        $robots = DataCenter::get( "rankmathseo/advanced/" . $field . "/data" );

                        if ( Helper::detectBoolVal( $robots ) === false ) {

                                $data = in_array( $field, $data ) ? \array_diff( $data, [ $field ] ) : $data;

                                continue;
                        }

                        if ( !in_array( $field, $data ) ) {
                                $data[] = $field;
                        }
                }

                if ( in_array( 'noindex', $data ) ) {
                        $data = \array_diff( $data, [ 'index' ] );
                } else {
                        $data[] = 'index';
                }

                return [ 'robots' => \array_unique( $data ) ];
        }

        
        private static function getRobotsAdv() {

                $data = DataCenter::isNewItem() ? [] : static::getMeta( 'advanced_robots', true );

                $data = Helper::isNonEmptyArray( $data ) ? $data : [];

                if ( DataCenter::canUpdate( 'rankmathseo/advanced/max_snippet' ) ) {
                        $maxSnippet            = DataCenter::get( "rankmathseo/advanced/max_snippet/data" );
                        $data[ 'max-snippet' ] = Helper::isNonEmptyStr( $maxSnippet ) ? $maxSnippet : '-1';
                }

                if ( DataCenter::canUpdate( 'rankmathseo/advanced/max_video_preview' ) ) {

                        $maxVideoPreview             = DataCenter::get( "rankmathseo/advanced/max_video_preview/data" );
                        $data[ 'max-video-preview' ] = Helper::isNonEmptyStr( $maxVideoPreview ) ? $maxVideoPreview : '-1';
                }

                if ( DataCenter::canUpdate( 'rankmathseo/advanced/max_image_preview' ) ) {

                        $maxImagePreview             = DataCenter::get( "rankmathseo/advanced/max_image_preview/data" );
                        $data[ 'max-image-preview' ] = Helper::autoFixStr( $maxImagePreview, [ "large", "standard", "none" ] );
                }

                return [ 'advanced_robots' => $data ];
        }

        
        protected static function getMeta( $key = '', $single = false ) {

                return [];
        }
}
