<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Attributes;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;

defined( 'WPIE__FILE__' ) || exit;


class NewAttribute {

        
        public static function register( $name = '', $slug = '' ) {

                if ( !Helper::isNonEmptyStr( $name ) || !Helper::isNonEmptyStr( $slug ) ) {
                        return 0;
                }

                if ( \taxonomy_exists( \wc_attribute_taxonomy_name( $name ) ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( 'Taxonomy already exists', 'wp-import-export' ) );
                        return 0;
                }

                // If the attribute does not exist, create it.
                $attributeId = \wc_create_attribute(
                        [
                                'name'         => $name,
                                'slug'         => $slug,
                                'type'         => 'select',
                                'order_by'     => 'menu_order',
                                'has_archives' => false
                        ]
                );

                if ( \is_wp_error( $attributeId ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $attributeId->get_error_message() );
                        return 0;
                }

                self::registerTaxonomy( $name );

                self::updateBase();

                return $attributeId;
        }

        
        private static function registerTaxonomy( $name ) {

                // Register as taxonomy while importing.
                $taxonomyName = \wc_attribute_taxonomy_name( $name );

                \register_taxonomy(
                        $taxonomyName,
                        apply_filters( 'woocommerce_taxonomy_objects_' . $taxonomyName, [ 'product' ] ),
                        apply_filters(
                                'woocommerce_taxonomy_args_' . $taxonomyName,
                                [
                                        'labels'       => [
                                                'name' => $name,
                                        ],
                                        'hierarchical' => true,
                                        'show_ui'      => false,
                                        'query_var'    => true,
                                        'rewrite'      => false,
                                ]
                        )
                );
        }

        
        private static function updateBase() {

                global $wc_product_attributes;

                // Set product attributes global.
                $wc_product_attributes = [];

                foreach ( \wc_get_attribute_taxonomies() as $taxonomy ) {
                        $wc_product_attributes[ \wc_attribute_taxonomy_name( $taxonomy->attribute_name ) ] = $taxonomy;
                }
        }
}
