<?php



namespace WpieApp\Modules\Export\Controller\Items\Taxonomy\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\Meta as BaseMeta;

defined( 'WPIE__FILE__' ) || exit;


class Meta extends BaseMeta implements InterfaceField {

        
        public static function get() {

                
                return \apply_filters( 'Wpie/Export/Taxonomy/Fields/Meta', parent::get(), Settings::getContentType() );
        }

        
        protected static function getMetaKeys( $contentType = '' ) {

                $contentType = Settings::getContentType();

                if ( !Helper::isNonEmptyArray( $contentType ) ) {
                        return [];
                }

                
                $limit = \apply_filters( 'Wpie/Export/Taxonomy/Fields/Meta/Limit', 500 );

                $excludes = static::getExcludesMetaQuery( $contentType );

                $contentTypes = DB::prepareData( $contentType );

                $keys = DB::wpdb()->get_col(
                        DB::wpdb()->prepare(
                                "SELECT DISTINCT `termmeta`.`meta_key`
				FROM " . DB::wpdb()->termmeta . " AS `termmeta`
				LEFT JOIN " . DB::wpdb()->terms . " AS `terms` ON ( `terms`.`term_id` = `termmeta`.`term_id` )
				LEFT JOIN " . DB::wpdb()->term_taxonomy . " AS `term_taxonomy` ON ( `terms`.`term_id` = `term_taxonomy`.`term_id` )
				WHERE `term_taxonomy`.`taxonomy` IN (" . $contentTypes . ") 
                                        $excludes
                                ORDER BY `termmeta`.`meta_key`
				LIMIT %d",
                                $limit
                        )
                );

                return $keys;
        }

        
        protected static function getExcludesMeta( $contentType = '' ) {

                $excludes = array_merge(
                        [ 'thumbnail_id' ],
                        parent::getExcludesMeta()
                );

                
                $excludes = apply_filters( 'Wpie/Export/Taxonomy/Fields/Meta/Excludes', $excludes, $contentType );

                return Helper::isNonEmptyArray( $excludes ) ? array_unique( $excludes ) : [];
        }

        
        protected static function getExcludesMetaQuery( $contentType = "" ) {

                $query = array_merge(
                        [
                                " AND `termmeta`.`meta_value` != '' "
                        ],
                        parent::getExcludesMetaQuery()
                );

                $keys = DB::prepareData( static::getExcludesMeta( $contentType ) );

                if ( Helper::isNonEmptyStr( $keys ) ) {
                        $query[] = " AND `termmeta`.`meta_key` NOT IN ( " . $keys . " ) ";
                }

                
                $query = \apply_filters( 'Wpie/Export/Taxonomy/Fields/Meta/Query/Where', $query, $contentType );

                return Helper::isNonEmptyArray( $query ) ? implode( " ", array_unique( $query ) ) : "";
        }
}
