<?php



namespace WpieApp\Modules\Import\Controller\File\Downloader\GoogleDrive;

use WP_Error;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use Google\Client;
use Google\Service\Drive;
use Masbug\Flysystem\GoogleDriveAdapter;
use WpieApp\Modules\Import\Controller\File\Downloader\Base\Manager as Filesystem;

defined( 'WPIE__FILE__' ) || exit;


class Manager extends Filesystem {

        
        public static function listContents() {

                $isConnect = self::connect();
                if ( is_wp_error( $isConnect ) ) {
                        return $isConnect;
                }
                return parent::listContents();
        }

        
        public static function Download() {

                $isConnect = self::connect();
                if ( is_wp_error( $isConnect ) ) {
                        return $isConnect;
                }
                return parent::Download();
        }

        
        private static function connect() {

                $clientId = Settings::getOption( 'uploder/options/client-id' );
                if ( !Helper::isNonEmptyStr( $clientId ) ) {
                        return new WP_Error( 'wpieError', __( "Google Drive API Client Id is empty", 'wp-import-export' ) );
                }

                $clientSecret = Settings::getOption( 'uploder/options/client-secret' );
                if ( !Helper::isNonEmptyStr( $clientSecret ) ) {
                        return new WP_Error( 'wpieError', __( "Google Drive API Client Secret is empty", 'wp-import-export' ) );
                }

                $token = Settings::getOption( 'uploder/options/token' );
                if ( !Helper::isNonEmptyStr( $clientSecret ) ) {
                        return new WP_Error( 'wpieError', __( "Google Drive API Refresh Token is empty", 'wp-import-export' ) );
                }

                $client = new Client();
                $client->setClientId( $clientId );
                $client->setClientSecret( $clientSecret );
                $client->refreshToken( $token );
                $client->setApplicationName( __( 'WP Import Export', 'wp-import-export' ) );

                Settings::getOption( 'uploder/options/token', $client->getAccessToken() );

                $service = new Drive( $client );

                parent::$adapter = new GoogleDriveAdapter( $service, '/' );

                return true;
        }

}
