<?php



namespace WpieApp\Modules\Import\Controller\File\Records;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Office\Reader\CSV\Reader;
use WpieApp\Modules\Import\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Csv {

        
        public static function get( $action = "", $options = [] ) {

                $reader = self::getReader();

                if ( \is_wp_error( $reader ) ) {
                        return $reader;
                }

                if ( "getTotal" === $action ) {
                        return $reader->count();
                } elseif ( "getFilterElements" === $action || "getLabels" === $action ) {
                        return $reader->getLabels();
                } elseif ( "getRow" === $action ) {

                        $row = isset( $options[ 'row' ] ) ? Helper::toInt( $options[ 'row' ] ) : 1;

                        $reader->goToRow( $row );

                        return $reader->current();
                }
        }

        
        public static function getReader( $isFilterFile = true ) {

                $hasTitle = Settings::getOption( "file/hasTitle" );

                $options = [
                        'delimiter' => Settings::getOption( "file/delimiter", null ),
                        'hasTitle'  => is_numeric( $hasTitle ) ? Helper::toInt( $hasTitle ) === 1 : true,
                        'enclosure' => Settings::getOption( "file/enclosure" )
                ];

                $file = $isFilterFile ? Settings::getFilePath() : Settings::getImportFilePath();

                $reader = new Reader();

                $isLoaded = $reader->load( $file, $options );

                if ( \is_wp_error( $isLoaded ) ) {
                        return $isLoaded;
                }

                self::setOptions( $reader->getDelimiter(), $reader->getEnclosure() );

                return $reader;
        }

        
        private static function setOptions( $delimiter = "", $enclosure = "" ) {

                if ( Settings::getOption( 'file/enclosure' ) !== "" ) {
                        return;
                }

                $hasTitle = Settings::getOption( "file/hasTitle" );

                Settings::setOptions( [
                        'file/delimiter' => $delimiter,
                        'file/enclosure' => $enclosure,
                        'file/hasTitle'  => is_numeric( $hasTitle ) ? Helper::toInt( $hasTitle ) : 1,
                ] );
        }
}
