<?php



namespace WpieApp\Modules\Import\Controller\File;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Core\Utils\Archive;

defined( 'WPIE__FILE__' ) || exit;


class Setup {

        
        public static function getFiles() {

                $file = Settings::get( 'file' );

                if ( !Helper::isArchive( $file ) ) {
                        return [ "files" => $file, 'isArchive' => false ];
                }

                $files = Archive::getFileList( Settings::getUploadFilePath(), [ "allowedExt" => Helper::getSupportedFileExt() ] );

                if ( \is_wp_error( $files ) ) {
                        return $files;
                }

                if ( Helper::isNonEmptyArray( $files ) && count( $files ) === 1 ) {
                        return self::setFile( array_shift( $files ) );
                }

                if ( Bundle::isBundle( $files ) ) {
                        return Bundle::setFile( $files );
                }

                return [ "files" => $files, 'isArchive' => true ];
        }

        
        public static function setFile( $file = "" ) {

                if ( !Helper::isNonEmptyStr( $file ) ) {
                        return new WP_Error( 'wpieError', __( "Set Empty Filename", 'wp-import-export' ) );
                }

                if ( !Helper::isArchive( Settings::getUploadFilePath() ) ) {
                        return new WP_Error( 'wpieError', __( "file is not archive", 'wp-import-export' ) );
                }

                $options = [ 'outputFolder' => Settings::getCurrentDir( "upload" ) ];

                $filePath = Archive::extract( Settings::getUploadFilePath(), $file, $options );

                Settings::setOption( "file", "" );

                Settings::setOption( "file/path", $file );

                Settings::setOption( "file/name", basename( $filePath ) );

                if ( \is_wp_error( $filePath ) ) {
                        return $filePath;
                }

                return [ "files" => $file, 'isArchive' => true ];
        }

        
        public static function getSheets() {

                $filename = Settings::getOption( 'file/name' );

                if ( !Helper::isNonEmptyStr( $filename ) ) {
                        $filename = Settings::get( "file" );
                }

                if ( !Helper::supportMultipleSheets( $filename ) ) {
                        return true;
                }

                $file = Settings::getCurrentDir( "upload" ) . DIRECTORY_SEPARATOR . $filename;

                $sheets = Helper::getSheets( $file );

                if ( Helper::isNonEmptyArray( $sheets ) && count( $sheets ) === 1 ) {
                        self::setSheet( array_shift( $sheets ) );
                        return true;
                }

                return [ "sheets" => $sheets ];
        }

        
        public static function setSheet( $sheet = "" ) {

                if ( !Helper::isNonEmptyStr( $sheet ) ) {
                        return new WP_Error( 'wpieError', __( "Set Empty Sheet", 'wp-import-export' ) );
                }

                Settings::setOption( "file/sheet/name", $sheet );

                return true;
        }
}
