<?php



namespace WpieApp\Modules\Import\Controller\Items\Base\Engines\Images;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Attachment {

        
        protected static $attachments = [];

        
        public static function import() {

                if ( DataCenter::canUpdate( "images/title" ) || DataCenter::canUpdate( "images/caption" ) || DataCenter::canUpdate( "images/description" ) || DataCenter::canUpdate( "images/alttext" ) ) {
                        static::insertData();
                        return true;
                }

                return false;
        }

        
        protected static function insertData() {

                if ( DataCenter::canUpdate( "images/source" ) ) {
                        static::$attachments = static::getSource();
                } else {
                        static::$attachments = static::getExisting();
                }

                if ( !Helper::isNonEmptyArray( static::$attachments ) ) {
                        return false;
                }

                $data = [
                        "title"       => static::getData( 'title' ),
                        "caption"     => static::getData( 'caption' ),
                        "description" => static::getData( 'description' ),
                        "alttext"     => static::getData( 'alttext' )
                ];

                if ( empty( $data[ "title" ] ) && empty( $data[ "caption" ] ) && empty( $data[ "description" ] ) && empty( $data[ "alttext" ] ) ) {
                        return false;
                }

                foreach ( static::$attachments as $key => $id ) {

                        $post = [];

                        if ( isset( $data[ "title" ][ $key ] ) ) {
                                $post[ 'post_title' ] = $data[ "title" ][ $key ];
                        }
                        if ( isset( $data[ "caption" ][ $key ] ) ) {
                                $post[ 'post_excerpt' ] = $data[ "caption" ][ $key ];
                        }
                        if ( isset( $data[ "description" ][ $key ] ) ) {
                                $post[ 'post_content' ] = $data[ "description" ][ $key ];
                        }
                        if ( isset( $data[ "alttext" ][ $key ] ) ) {
                                \update_post_meta( $id, '_wp_attachment_image_alt', $data[ "alttext" ][ $key ] );
                        }

                        if ( empty( $post ) ) {
                                continue;
                        }

                        DB::wpdb()->update( DB::wpdb()->posts, $post, [ 'ID' => $id ] );

                        \clean_attachment_cache( $id );
                }

                unset( $data );
        }

        
        protected static function getSource() {
                return Source::getAttachments();
        }

        
        protected static function getExisting() {
                return Existing::getAttachments();
        }

        
        protected static function getData( $option = "" ) {

                if ( !DataCenter::canUpdate( "images/" . $option ) ) {
                        return [];
                }

                $imageData = DataCenter::get( "images/" . $option . "/data" );

                if ( !Helper::isNonEmptyStr( $imageData ) ) {
                        return [];
                }

                $data = Helper::strToArr( $imageData, "\n" );

                if ( count( $data ) <= 1 ) {

                        $separator = DataCenter::get( "images/" . $option . "/separator" );

                        $data = Helper::strToArr( $imageData, $separator );
                }

                //If names list are not same with source, none of apply
                if ( count( static::$attachments ) !== count( $data ) ) {
                        return [];
                }
                return $data;
        }

        
        public static function search( $attach = "" ) {

                if ( !Helper::isNonEmptyStr( $attach ) ) {
                        return 0;
                }

                return DB::wpdb()->get_var(
                                DB::wpdb()->prepare(
                                        "
                                                SELECT posts.ID
                                                FROM " . DB::wpdb()->posts . "  AS posts
                                                INNER JOIN " . DB::wpdb()->postmeta . " AS postmeta ON posts.ID = postmeta.post_id
                                                WHERE posts.post_type = 'attachment'
                                                AND ( 
							(
								postmeta.meta_key = '_wpie_source_url'    
								AND postmeta.meta_value = %s   
							)
							OR
							(
								postmeta.meta_key = '_wp_attached_file'                                              
								AND ( 
									postmeta.meta_value = %s 
									OR postmeta.meta_value Like %s 
									OR postmeta.meta_value = %s 
									OR postmeta.meta_value Like %s
								)
							)
							OR							
							(
								post_title = %s    
							)
						)
                                                LIMIT 0, 1
                                        ",
                                        esc_url_raw( $attach ),
                                        basename( $attach ),
                                        "%/" . basename( $attach ),
                                        sanitize_file_name( basename( $attach ) ),
                                        "%/" . sanitize_file_name( basename( $attach ) ),
                                        basename( $attach )
                                )
                );
        }
}
