<?php



namespace WpieApp\Modules\Import\Controller\Items\Comment;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Comment\AutoSearch\Data;

defined( 'WPIE__FILE__' ) || exit;


class AutoSearch {

        
        public static function get() {

                $comments = self::tryPostAndAuthor();

                if ( 0 === $comments ) {
                        return 0;
                }

                $ids = self::tryDateAndContentData( $comments );

                $ids = (( 0 === $ids || false === $ids ) && Helper::isNonEmptyArray( $comments ) ) ? self::tryDate( $comments ) : $ids;

                if ( 0 === $ids ) {
                        return 0;
                }

                if ( false !== $ids ) {
                        $comments = $ids;
                }

                $ipAddressMatch = self::tryIp( $comments );

                if ( 0 !== $ipAddressMatch ) {
                        $comments = $ipAddressMatch;
                }

                return is_array( $comments ) ? array_shift( $comments ) : 0;
        }

        
        private static function tryPostAndAuthor() {

                $postId = Data::getPost();

                $author = Data::getAuthor();

                if ( ( false === $postId || $postId < 1 ) && (false === $author || !Helper::isNonEmptyStr( $author ) ) ) {
                        return false;
                }

                $query = ( false === $postId || $postId < 1 ) ? '' : DB::wpdb()->prepare( '`comment_post_ID` = %d', $postId );

                $query .= (false === $author ) ? '' : ($query === '' ? '' : ' AND ') . DB::wpdb()->prepare( '`comment_author_email` = %s', $author );

                return self::runQuery( $query );
        }

        
        private static function tryDateAndContentData( $comments = [] ) {

                $content = Data::getContent();
                $content = ( false === $content ? '' : $content);

                $date = Data::getDate();
                $date = ( false === $date ? '' : $date);

                return self::tryDateAndContent( $content, $date, $comments );
        }

        
        private static function tryDate( $comments = [] ) {

                $date = Data::getDate();

                if ( false === $date || !Helper::isNonEmptyStr( $date ) || !Helper::isNonEmptyArray( $comments ) ) {
                        return false;
                }

                return self::tryDateAndContent( '', $date, $comments );
        }

        
        public static function tryDateAndContent( $content = '', $date = '', $comments = [] ) {

                if (
                        (!Helper::isNonEmptyStr( $content ) && !Helper::isNonEmptyStr( $date ) ) ||
                        ((!Helper::isNonEmptyStr( $content ) || !Helper::isNonEmptyStr( $date ) ) && !Helper::isNonEmptyArray( $comments ) ) ) {
                        return false;
                }

                $query = Helper::isNonEmptyStr( $content ) ? DB::wpdb()->prepare( '`comment_content` = %s', $content ) : '';

                if ( Helper::isNonEmptyStr( $date ) ) {

                        $query .= (Helper::isNonEmptyStr( $query ) ? ' AND ' : '') . DB::wpdb()->prepare( '( `comment_date_gmt` = %s OR `comment_date` = %s )', $date, $date );
                }

                if ( Helper::isNonEmptyArray( $comments ) ) {

                        $query = ' ( ' . $query . ' ) AND `comment_ID` IN (' . DB::prepareData( $comments ) . ')';
                }

                return self::runQuery( $query );
        }

        
        private static function tryIp( $comments = [] ) {

                if ( !Helper::isNonEmptyArray( $comments ) || 1 === count( $comments ) ) {
                        return $comments;
                }

                $ipAddress = Data::getIp();

                if ( false === $ipAddress || !Helper::isNonEmptyStr( $ipAddress ) ) {
                        return false;
                }

                $query = DB::wpdb()->prepare( '`comment_author_IP` = %s', $ipAddress );

                if ( Helper::isNonEmptyArray( $comments ) ) {

                        $query = ' ( ' . $query . ' ) AND `comment_ID` IN (' . DB::prepareData( $comments ) . ')';
                }

                return self::runQuery( $query );
        }

        
        private static function runQuery( $query = '' ) {

                if ( !Helper::isNonEmptyStr( $query ) ) {
                        return false;
                }

                $comments = DB::wpdb()->get_results(
                        'SELECT `comment_ID` FROM ' . DB::wpdb()->comments
                        . ' WHERE  ' . $query . ' AND `comment_post_ID` > 0 ORDER BY `comment_ID` ASC',
                        ARRAY_A
                );

                return empty( $comments ) ? 0 : \wp_list_pluck( $comments, 'comment_ID' );
        }

}
