<?php



namespace WpieApp\Modules\License\Controller;

use WP_Error;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Utils\License as LicenseManager;

defined( 'WPIE__FILE__' ) || exit;


class License {

        
        public static function activate( $license = "" ) {

                if ( !Helper::isNonEmptyStr( $license ) ) {
                        return new WP_Error( 'wpieError', __( 'Empty Purchase Code', 'wp-import-export' ) );
                }

                $license = trim( $license );

                if ( !preg_match( "/^([a-f0-9]{8})-(([a-f0-9]{4})-){3}([a-f0-9]{12})$/i", $license ) ) {
                        return new WP_Error( 'wpieError', __( 'Invalid Purchase Code', 'wp-import-export' ) );
                }
	$data = [
	'license' => $license,
	'url'     => \home_url(),
	'expire'  => "01/01/2099"
	];
	
	LicenseManager::update( $data );
	
	$data[ 'msg' ] = __( 'License Successfully activated', 'wp-import-export' );
	return [
	'isExpired' => false,
	'msg'       => __( 'License Successfully activated', 'wp-import-export' )
	];
                $post = [
                        'vlm_api_action' => "license_activate",
                        'plugin'         => basename( WPIE_BASENAME, '.php' ),
                        'license'        => base64_encode( $license ),
                        'version'        => WPIE_VERSION,
                        'wp_name'        => get_bloginfo( 'name' ),
                        'wp_url'         => \home_url(),
                        'wp_version'     => get_bloginfo( 'version' ),
                        'wp_language'    => get_bloginfo( 'language' ),
                        'wp_timezone'    => get_option( 'timezone_string' ),
                ];

                $response = self::request( WPIE_API_URL, $post );

                if ( \is_wp_error( $response ) ) {
                        return $response;
                }
                if ( !is_array( $response ) || !isset( $response[ 'success' ] ) || Helper::isEmpty( $response[ 'success' ] ) ) {

                        return new \WP_Error( 'wpieError', __( 'unexpected error occurred while activation of Purchase Code', 'wp-import-export' ) );
                }
                if ( is_array( $response ) && isset( $response[ 'success' ] ) && $response[ 'success' ] === false && isset( $response[ 'data' ] ) ) {

                        return new \WP_Error( 'wpieError', $response[ 'data' ] );
                }

                $result = isset( $response[ 'data' ] ) ? $response[ 'data' ] : "";

                $expire = isset( $result[ 'expire' ] ) ? $result[ 'expire' ] : "";

                $data = [
                        'license' => $license,
                        'url'     => \home_url(),
                        'expire'  => Date::get( $expire )
                ];

                LicenseManager::update( $data );

                $data[ 'msg' ] = __( 'License Successfully activated', 'wp-import-export' );

                return [
                        'expire'    => $data[ 'expire' ],
                        'isExpired' => strtotime( $expire ) < strtotime( "today" ),
                        'msg'       => __( 'License Successfully activated', 'wp-import-export' )
                ];
        }

        
        public static function deactivate() {
	LicenseManager::remove();
	return __( 'License Successfully deactivated', 'wp-import-export' );
                if ( !WPIE_PRO ) {
                        return true;
                }

                $license = LicenseManager::get();

                if ( false === $license ) {
                        return new \WP_Error( 'wpieError', __( 'License Not found', 'wp-import-export' ) );
                }

                $post = [
                        'vlm_api_action' => "license_deactivate",
                        'license'        => base64_encode( $license ),
                        'wp_url'         => \home_url(),
                ];

                $response = self::request( WPIE_API_URL, $post );

                if ( \is_wp_error( $response ) ) {
                        return $response;
                }
                if ( !is_array( $response ) || !isset( $response[ 'success' ] ) || Helper::isEmpty( $response[ 'success' ] ) ) {

                        return new \WP_Error( 'wpieError', __( 'unexpected error occurred while deactivation of Purchase Code', 'wp-import-export' ) );
                }
                if ( is_array( $response ) && isset( $response[ 'success' ] ) && $response[ 'success' ] === false && isset( $response[ 'data' ] ) ) {

                        return new \WP_Error( 'wpieError', $response[ 'data' ] );
                }

                LicenseManager::remove();

                return __( 'License Successfully deactivated', 'wp-import-export' );
        }

        private static function request( $url = '', $body = [] ) {

                $response = \wp_remote_post( $url, array(
                        'timeout' => 30,
                        'body'    => $body
                        ) );

                if ( \is_wp_error( $response ) ) {
                        return $response;
                } elseif ( \wp_remote_retrieve_response_code( $response ) != 200 ) {
                        return new \WP_Error( 'wpieError', \wp_remote_retrieve_response_message( $response ) );
                }

                $json = \json_decode( \wp_remote_retrieve_body( $response ), true );

                if ( $json === null ) {
                        return \wp_remote_retrieve_body( $response );
                }
                return $json;
        }
}
