<?php



namespace WpieApp\Modules\Logs\Controller;

use WP_Error;
use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;
use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Status {

        
        public static function update( $status = '', $ids = [] ) {

                if ( !Helper::isNonEmptyStr( $status ) ) {
                        return new WP_Error( 'wpie_import_error', __( 'Invalid status', 'wp-import-export' ) );
                }
                if ( !Helper::isNonEmptyArray( $ids ) ) {
                        return new WP_Error( 'wpie_import_error', __( 'Invalid entries detected', 'wp-import-export' ) );
                }

                switch ( $status ) {
                        case 'paused':
                                self::pause( $ids );
                                break;
                        case 'stop':
                                self::stop( $ids );
                                break;
                        case 'resume':
                                self::resume( $ids );
                                break;
                        case 'background':
                                self::background( $ids );
                                break;
                }
                return true;
        }

        
        public static function pause( $ids ) {

                $placeholders = implode( ', ', array_fill( 0, count( $ids ), '%d' ) );

                return DB::wpdb()->query( DB::wpdb()->prepare( "UPDATE " . DB::getPluginTable() . " SET `status` = 'paused' WHERE `status` IN ('processing','waiting') AND `id` IN ($placeholders) ", $ids ) );
        }

        
        public static function stop( $ids ) {

                $placeholders = implode( ', ', array_fill( 0, count( $ids ), '%d' ) );

                return DB::wpdb()->query( DB::wpdb()->prepare( "UPDATE " . DB::getPluginTable() . " SET `status` = 'stopped' WHERE `status` IN ('processing','waiting','paused') AND `id` IN ($placeholders) ", $ids ) );
        }

        
        public static function resume( $ids ) {

                $placeholders = implode( ', ', array_fill( 0, count( $ids ), '%d' ) );

                return DB::wpdb()->query( DB::wpdb()->prepare( "UPDATE " . DB::getPluginTable() . " SET `status` = 'processing' WHERE `status` IN ('paused') AND `process_type` = 'background' AND `id` IN ($placeholders) ", $ids ) );
        }

        
        public static function background( $ids ) {


                $placeholders = implode( ', ', array_fill( 0, count( $ids ), '%d' ) );

                return DB::wpdb()->query( DB::wpdb()->prepare( "UPDATE " . DB::getPluginTable() . " SET `process_type` = 'background', `status` = 'processing' WHERE `status` IN ('processing','waiting','paused') AND `id` IN ($placeholders) ", $ids ) );
        }
}
